==> v28.0.0.zip: nextcloud/apps/updatenotification/l10n/nb.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er tilgjengelig. Få mer informasjon om å oppdatere.",
    "Channel updated" : "Kanal oppdatert",
    "Web updater is disabled" : "Web-oppdaterer er deaktivert",
    "Update notifications" : "Oppdateringsvarsel",
    "The update server could not be reached since %d days to check for new updates." : "Har ikke oppnådd kontakt med oppdateringsserveren på %d dager for å se etter nye oppdateringer.",
    "Please check the Nextcloud and server log files for errors." : "Se i Nextcloud- og server-loggen etter feil.",
    "Update to %1$s is available." : "Oppdatering til %1$s er tilgjengelig.",
    "Update to {serverAndVersion} is available." : "Oppdatering til {serverAndVersion} er tilgjengelig.",
    "Update for {app} to version %s is available." : "Oppdatering for {app} til versjon %s er tilgjengelig.",
    "Update notification" : "Oppdateringsvarsel",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Viser oppdateringsvarsler for Nextcloud og gir SSO for oppdatereren.",
    "Update" : "Oppdater",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Versjonen du kjører vedlikeholdes ikke lengre. Vennligst sørg for å oppdatere til en støttet versjon så snart som mulig.",
    "Apps missing compatible version" : "Apper som mangler kompatibel versjon",
    "View in store" : "Vis i butikk",
    "Apps with compatible version" : "Apper med kompatibel versjon",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Vær oppmerksom på at web-oppdaterer ikke anbefales med mer enn 100 brukere! Bruk kommandolinjen i stedet!",
    "Open updater" : "Åpne oppdaterer",
    "Download now" : "Last ned nå",
    "What's new?" : "Hva er nytt?",
    "View changelog" : "Se endringslogg",
    "The update check is not yet finished. Please refresh the page." : "Oppdateringssjekken er ikke ferdig, vennligst oppdater siden.",
    "Your version is up to date." : "Du har nyeste versjon.",
    "A non-default update server is in use to be checked for updates:" : "En ikke-forvalgt oppdateringsserver brukes for å se etter oppdateringer:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Du kan alltid oppdatere til en nyere versjon. Men du kan aldri nedgradere til en mer stabil versjon.",
    "Notify members of the following groups about available updates:" : "Informer medlemmene i følgende grupper om tilgjengelig oppdateringer:",
    "Only notifications for app updates are available." : "Bare varsler for appoppdateringer er tilgjengelige.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valgte oppdateringskanalen gjør dedikerte varsler til denne serveren utdatert.",
    "The selected update channel does not support updates of the server." : "Den valgte oppdateringskanalen tilbyr ikke oppdateringer av serveren.",
    "A new version is available: <strong>{newVersionString}</strong>" : "En ny versjon er tilgjengelig: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Merk at etter en ny utgivelse vises oppdateringen først etter den første mindre utgivelsen eller senere. Vi ruller ut nye versjoner spredt over tid til brukerne våre og hopper noen ganger over en versjon når problemer blir funnet. Finn ut mer om oppdateringer og utgivelseskanaler på {link}",
    "Checked on {lastCheckedDate}" : "Sist sjekket {lastCheckedDate}",
    "Checking apps for compatible versions" : "Sjekker apper for kompatible versjoner",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Forsikre deg om at <samp>appstoreenabled</samp> ikke er satt til false i config.php.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Kunne ikke koble til appbutikken eller ingen oppdateringer har blitt returnert i det hele tatt. Søk manuelt etter oppdateringer eller sørg for at serveren din har tilgang til internett og kan koble til appbutikken.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Alle</strong> apper har en kompatibel versjon for denne Nextcloud-versjonen tilgjengelig.",
    "Enterprise" : "Bedrift",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "For bedriftsbruk. Tilbyr alltid det siste oppdateringsnivået, men oppdateres ikke til neste store utgivelse umiddelbart. Denne oppdateringen skjer når Nextcloud GmbH har gjort ytterligere herding og testing for store og oppdragskritiske distribusjoner. Denne kanalen er bare tilgjengelig for kunder og tilbyr Nextcloud Enterprise-pakken.",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Den siste stabile versjonen. Den er egnet for vanlig bruk og vil alltid oppdatere til den siste store versjonen.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "En pre-release versjon bare for testing av nye funksjoner, ikke for produksjonsmiljøer.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> apper har ingen kompatibel versjon for denne Nextcloud-versjonen tilgjengelig.","<strong>%n</strong> apper har ingen kompatibel versjon for denne Nextcloud-versjonen tilgjengelig."],
    "Please use the command line updater to update." : "Bruk kommandolinjen for å oppdatere.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Du kan endre oppdateringskanalen nedenfor som også påvirker appadministrasjonssiden. F.eks. etter å ha byttet til betakanalen, vil betaappoppdateringer bli tilbudt deg på appadministrasjonssiden.",
    "Update channel:" : "Oppdateringskanal:"
},
"nplurals=2; plural=(n != 1);");

==> v28.0.2rc3.zip: nextcloud/apps/updatenotification/l10n/nb.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er tilgjengelig. Få mer informasjon om å oppdatere.",
    "Channel updated" : "Kanal oppdatert",
    "Web updater is disabled" : "Web-oppdaterer er deaktivert",
    "Update notifications" : "Oppdateringsvarsel",
    "The update server could not be reached since %d days to check for new updates." : "Har ikke oppnådd kontakt med oppdateringsserveren på %d dager for å se etter nye oppdateringer.",
    "Please check the Nextcloud and server log files for errors." : "Se i Nextcloud- og server-loggen etter feil.",
    "Update to %1$s is available." : "Oppdatering til %1$s er tilgjengelig.",
    "Update to {serverAndVersion} is available." : "Oppdatering til {serverAndVersion} er tilgjengelig.",
    "Update for {app} to version %s is available." : "Oppdatering for {app} til versjon %s er tilgjengelig.",
    "Update notification" : "Oppdateringsvarsel",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Viser oppdateringsvarsler for Nextcloud og gir SSO for oppdatereren.",
    "Update" : "Oppdater",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Versjonen du kjører vedlikeholdes ikke lengre. Vennligst sørg for å oppdatere til en støttet versjon så snart som mulig.",
    "Apps missing compatible version" : "Apper som mangler kompatibel versjon",
    "View in store" : "Vis i butikk",
    "Apps with compatible version" : "Apper med kompatibel versjon",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Vær oppmerksom på at web-oppdaterer ikke anbefales med mer enn 100 brukere! Bruk kommandolinjen i stedet!",
    "Open updater" : "Åpne oppdaterer",
    "Download now" : "Last ned nå",
    "What's new?" : "Hva er nytt?",
    "View changelog" : "Se endringslogg",
    "The update check is not yet finished. Please refresh the page." : "Oppdateringssjekken er ikke ferdig, vennligst oppdater siden.",
    "Your version is up to date." : "Du har nyeste versjon.",
    "A non-default update server is in use to be checked for updates:" : "En ikke-forvalgt oppdateringsserver brukes for å se etter oppdateringer:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Du kan alltid oppdatere til en nyere versjon. Men du kan aldri nedgradere til en mer stabil versjon.",
    "Notify members of the following groups about available updates:" : "Informer medlemmene i følgende grupper om tilgjengelig oppdateringer:",
    "Only notifications for app updates are available." : "Bare varsler for appoppdateringer er tilgjengelige.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valgte oppdateringskanalen gjør dedikerte varsler til denne serveren utdatert.",
    "The selected update channel does not support updates of the server." : "Den valgte oppdateringskanalen tilbyr ikke oppdateringer av serveren.",
    "A new version is available: <strong>{newVersionString}</strong>" : "En ny versjon er tilgjengelig: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Merk at etter en ny utgivelse vises oppdateringen først etter den første mindre utgivelsen eller senere. Vi ruller ut nye versjoner spredt over tid til brukerne våre og hopper noen ganger over en versjon når problemer blir funnet. Finn ut mer om oppdateringer og utgivelseskanaler på {link}",
    "Checking apps for compatible versions" : "Sjekker apper for kompatible versjoner",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Forsikre deg om at <samp>appstoreenabled</samp> ikke er satt til false i config.php.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Kunne ikke koble til appbutikken eller ingen oppdateringer har blitt returnert i det hele tatt. Søk manuelt etter oppdateringer eller sørg for at serveren din har tilgang til internett og kan koble til appbutikken.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Alle</strong> apper har en kompatibel versjon for denne Nextcloud-versjonen tilgjengelig.",
    "Enterprise" : "Bedrift",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "For bedriftsbruk. Tilbyr alltid det siste oppdateringsnivået, men oppdateres ikke til neste store utgivelse umiddelbart. Denne oppdateringen skjer når Nextcloud GmbH har gjort ytterligere herding og testing for store og oppdragskritiske distribusjoner. Denne kanalen er bare tilgjengelig for kunder og tilbyr Nextcloud Enterprise-pakken.",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Den siste stabile versjonen. Den er egnet for vanlig bruk og vil alltid oppdatere til den siste store versjonen.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "En pre-release versjon bare for testing av nye funksjoner, ikke for produksjonsmiljøer.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> apper har ingen kompatibel versjon for denne Nextcloud-versjonen tilgjengelig.","<strong>%n</strong> apper har ingen kompatibel versjon for denne Nextcloud-versjonen tilgjengelig."],
    "Please use the command line updater to update." : "Bruk kommandolinjen for å oppdatere.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Du kan endre oppdateringskanalen nedenfor som også påvirker appadministrasjonssiden. F.eks. etter å ha byttet til betakanalen, vil betaappoppdateringer bli tilbudt deg på appadministrasjonssiden.",
    "Update channel:" : "Oppdateringskanal:",
    "Checked on {lastCheckedDate}" : "Sist sjekket {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
